Data (`sunpy.data`)
*******************

``sunpy.data`` contains ways to access sample data and small test files for
running the sunpy test suite.

.. automodapi:: sunpy.data
   :include-all-objects:

.. automodapi:: sunpy.data.sample

.. automodapi:: sunpy.data.test

.. automodapi:: sunpy.data.data_manager

.. automodapi:: sunpy.data.data_manager.downloader

.. automodapi:: sunpy.data.data_manager.storage
